@@ -5,45 +5,45 @@
 using namespace Quotient;
 
 SetRoomAliasJob::SetRoomAliasJob(const QString& roomAlias, const QString& roomId)
-    : BaseJob(HttpVerb::Put, QStringLiteral("SetRoomAliasJob"),
+    : BaseJob(HttpVerb::Put, u"SetRoomAliasJob"_s,
               makePath("/_matrix/client/v3", "/directory/room/", roomAlias))
 {
     QJsonObject _dataJson;
-    addParam<>(_dataJson, QStringLiteral("room_id"), roomId);
+    addParam(_dataJson, "room_id"_L1, roomId);
     setRequestData({ _dataJson });
 }
 
-QUrl GetRoomIdByAliasJob::makeRequestUrl(QUrl baseUrl, const QString& roomAlias)
+QUrl GetRoomIdByAliasJob::makeRequestUrl(const HomeserverData& hsData, const QString& roomAlias)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/directory/room/", roomAlias));
 }
 
 GetRoomIdByAliasJob::GetRoomIdByAliasJob(const QString& roomAlias)
-    : BaseJob(HttpVerb::Get, QStringLiteral("GetRoomIdByAliasJob"),
+    : BaseJob(HttpVerb::Get, u"GetRoomIdByAliasJob"_s,
               makePath("/_matrix/client/v3", "/directory/room/", roomAlias), false)
 {}
 
-QUrl DeleteRoomAliasJob::makeRequestUrl(QUrl baseUrl, const QString& roomAlias)
+QUrl DeleteRoomAliasJob::makeRequestUrl(const HomeserverData& hsData, const QString& roomAlias)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/directory/room/", roomAlias));
 }
 
 DeleteRoomAliasJob::DeleteRoomAliasJob(const QString& roomAlias)
-    : BaseJob(HttpVerb::Delete, QStringLiteral("DeleteRoomAliasJob"),
+    : BaseJob(HttpVerb::Delete, u"DeleteRoomAliasJob"_s,
               makePath("/_matrix/client/v3", "/directory/room/", roomAlias))
 {}
 
-QUrl GetLocalAliasesJob::makeRequestUrl(QUrl baseUrl, const QString& roomId)
+QUrl GetLocalAliasesJob::makeRequestUrl(const HomeserverData& hsData, const QString& roomId)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/rooms/", roomId, "/aliases"));
 }
 
 GetLocalAliasesJob::GetLocalAliasesJob(const QString& roomId)
-    : BaseJob(HttpVerb::Get, QStringLiteral("GetLocalAliasesJob"),
+    : BaseJob(HttpVerb::Get, u"GetLocalAliasesJob"_s,
               makePath("/_matrix/client/v3", "/rooms/", roomId, "/aliases"))
 {
-    addExpectedKey("aliases");
+    addExpectedKey(u"aliases"_s);
 }
